Learn R Programming

ScrabbleScore (version 1.0)

is.twl06.word: Verifies that word belong to the twl06 list.

Description

Only certain words are officially approved for Scrabble tournament play. They are collected in a dataset revered to as twl06

Usage

is.twl06.word(w)

Arguments

w
Word or vector of words to check for inclusion in the twl06 list

References

https://en.wikipedia.org/wiki/Official_Tournament_and_Club_Word_List

Examples

Run this code
is.twl06.word("zzz")
is.twl06.word(c("zzz","zzzz"))

Run the code above in your browser using DataLab